@@ -1,15 +1,16 @@
 # -*- coding: utf-8 -*-
 
-import numpy as np
-import tinyarray as ta
-import scipy.linalg as la
 from itertools import product
 from functools import lru_cache
 from fractions import Fraction
 from numbers import Number
 from collections import OrderedDict
+
+import numpy as np
+import tinyarray as ta
+import scipy.linalg as la
 import sympy
-from copy import deepcopy
+from sympy.matrices.matrices import MatrixBase
 
 from .linalg import prop_to_id, _inv_int, allclose
 from .model import Model
@@ -88,7 +89,7 @@ def _is_antisymmetric(a):
 
 def is_sympy_matrix(R):
     # Returns True if the input is a sympy.Matrix or sympy.ImmutableMatrix.
-    return isinstance(R, (sympy.ImmutableMatrix, sympy.matrices.MatrixBase))
+    return isinstance(R, (sympy.ImmutableMatrix, MatrixBase))
 
 
 class PointGroupElement:
@@ -139,7 +140,7 @@ class PointGroupElement:
             pass
         elif isinstance(R, ta.ndarray_float):
             R = _make_int(R)
-        elif isinstance(R, sympy.matrices.MatrixBase):
+        elif isinstance(R, MatrixBase):
             R = sympy.ImmutableMatrix(R)
             R = _make_int(R)
         elif isinstance(R, np.ndarray):
@@ -451,8 +452,8 @@ def rotation(angle, axis=None, inversion=False, U=None, spin=None):
 def mirror(axis, U=None, spin=None):
     """Return a mirror operator
 
-    Parameters:
-    -----------
+    Parameters
+    ----------
     axis : ndarray
         Normal of the mirror. The dimensionality of the operator is the same
         as the length of `axis`.
@@ -468,8 +469,8 @@ def mirror(axis, U=None, spin=None):
         of mirror operator is `U = exp(-i π n⋅s)` where n is normalized to 1. In 2D the
         axis is treated as x and y coordinates. Only one of `U` and `spin` may be provided.
 
-    Returns:
-    --------
+    Returns
+    -------
     P : PointGroupElement
 
     Notes:
@@ -503,8 +504,8 @@ class ContinuousGroupGenerator:
 
     with λ a real parameter.
 
-    Parameters:
-    -----------
+    Parameters
+    ----------
     R: ndarray (optional)
         Real space rotation generator: Hermitian antisymmetric.
         If not provided, the zero matrix is used.
@@ -564,13 +565,13 @@ class ContinuousGroupGenerator:
 def generate_group(gens):
     """Generate group from gens
 
-    Parameters:
-    -----------
+    Parameters
+    ----------
     gens : iterable of PointGroupElement
         generator set of the group
 
-    Returns:
-    --------
+    Returns
+    -------
     group : set of PointGroupElement
         group generated by gens, closed under multiplication
     """
@@ -603,13 +604,13 @@ def generate_subgroups(group):
     """Generate all subgroups of group, including the trivial group
     and itself.
 
-    Parameters:
-    -----------
+    Parameters
+    ----------
     group : set of PointGroupElement
         A closed group as set of its elements.
 
-    Returns:
-    --------
+    Returns
+    -------
     subgroups : dict of forzenset: set
         frozesets are the subgroups, sets are a generator set of the
         subgroup.
@@ -654,8 +655,8 @@ def square(tr=True, ph=True, generators=False, spin=None):
     """
     Generate square point group in standard basis.
 
-    Parameters:
-    -----------
+    Parameters
+    ----------
     tr, ph : bool (default True)
         Whether to include time-reversal and particle-hole
         symmetry.
@@ -673,8 +674,8 @@ def square(tr=True, ph=True, generators=False, spin=None):
         possible to deduce the unitary representation of particle-hole symmetry from
         spin alone. In this case construct the particle-hole operator manually.
 
-    Returns:
-    --------
+    Returns
+    -------
     set of PointGroupElement objects with integer rotations
 
     Notes:
@@ -707,8 +708,8 @@ def cubic(tr=True, ph=True, generators=False, spin=None):
     """
     Generate cubic point group in standard basis.
 
-    Parameters:
-    -----------
+    Parameters
+    ----------
     tr, ph : bool (default True)
         Whether to include time-reversal and particle-hole
         symmetry.
@@ -726,8 +727,8 @@ def cubic(tr=True, ph=True, generators=False, spin=None):
         particle-hole symmetry from spin alone. In this case construct the
         particle-hole operator manually.
 
-    Returns:
-    --------
+    Returns
+    -------
     set of PointGroupElement objects with integer rotations
 
     Notes:
@@ -760,8 +761,8 @@ def hexagonal(dim=2, tr=True, ph=True, generators=False, sympy_R=True, spin=None
     Mirror symmetries with the main coordinate axes as normals are included.
     In 3D the hexagonal axis is the z axis.
 
-    Parameters:
-    -----------
+    Parameters
+    ----------
     dim : int (default 2)
         Real sapce dimensionality, 2 or 3.
     tr, ph : bool (default True)
@@ -784,8 +785,8 @@ def hexagonal(dim=2, tr=True, ph=True, generators=False, sympy_R=True, spin=None
         possible to deduce the unitary representation of particle-hole symmetry from
         spin alone. In this case construct the particle-hole operator manually.
 
-    Returns:
-    --------
+    Returns
+    -------
     set of PointGroupElements
 
     Notes:
@@ -986,7 +987,7 @@ def pretty_print_pge(g, full=False, latex=False):
         else:
             az_name = ""
         name = (az_name if (rot_name == '1' and az_name != "")
-                else rot_name + (" " if az_name is not "" else "") + az_name)
+                else rot_name + (" " if az_name != "" else "") + az_name)
     return '$' + name + '$' if latex else name
 
 
@@ -1107,8 +1108,8 @@ def spin_matrices(s, include_0=False):
     """
     Construct spin-s matrices for any half-integer spin.
 
-    Parameters:
-    -----------
+    Parameters
+    ----------
 
     s : float or int
         Spin representation to use, must be integer or half-integer.
@@ -1116,8 +1117,8 @@ def spin_matrices(s, include_0=False):
         If `include_0` is True, S[0] is the identity, indices 1, 2, 3
         correspond to x, y, z. Otherwise indices 0, 1, 2 are x, y, z.
 
-    Returns:
-    --------
+    Returns
+    -------
 
     ndarray
         Sequence of spin-s operators in the standard spin-z basis.
@@ -1144,8 +1145,8 @@ def spin_rotation(n, s, roundint=False):
     vector n (in radian units) with angular momentum `s`, given by
     `U = exp(-i n⋅s)`.
 
-    Parameters:
-    -----------
+    Parameters
+    ----------
 
     n : iterable
         Rotation vector. Its norm is the rotation angle in radians.
@@ -1158,8 +1159,8 @@ def spin_rotation(n, s, roundint=False):
     roundint : bool (default False)
         If roundint is True, result is converted to integer tinyarray if possible.
 
-    Returns:
-    --------
+    Returns
+    -------
     U : ndarray
         Unitary spin rotation matrix of the same shape as the spin matrices or
         `(2*s + 1, 2*s + 1)`.
@@ -1226,8 +1227,8 @@ def symmetry_from_permutation(R, perm, norbs, onsite_action=None,
                               antiunitary=False, antisymmetry=False):
     """Construct symmetry operator for lattice systems with multiple sites.
 
-    Parameters:
-    -----------
+    Parameters
+    ----------
     R : real space rotation
     perm : dict : {site: image_site}
         permutation of the sites under the symmetry action
@@ -1240,8 +1241,8 @@ def symmetry_from_permutation(R, perm, norbs, onsite_action=None,
         is used on every site. Size of the arrays must be consistent with norbs.
     antiunitary, antisymmetry : bool
 
-    Returns:
-    --------
+    Returns
+    -------
     g : PointGroupElement
         PointGroupElement corresponding to the operation.
 
