@@ -1,19 +1,22 @@
+from itertools import product
+from copy import copy
+from numbers import Number
+from warnings import warn
+from functools import lru_cache
+from collections import defaultdict, abc, UserDict
+
 import numpy as np
 import scipy
 import tinyarray as ta
 import scipy.linalg as la
-from itertools import product
-from copy import copy, deepcopy
-from numbers import Number
-from warnings import warn
-from functools import lru_cache
 import sympy
+from sympy.core.numbers import One
+from sympy.matrices.matrices import MatrixBase
 from sympy.core.basic import Basic
 from sympy.core.function import AppliedUndef
-from collections import defaultdict, abc, UserDict
-from .linalg import prop_to_id, allclose
 
-from . import kwant_continuum
+from .linalg import prop_to_id, allclose
+from . import kwant_continuum, _scipy_patch
 
 _commutative_momenta = [kwant_continuum.make_commutative(k, k)
            for k in kwant_continuum.momentum_operators]
@@ -60,7 +63,7 @@ class BlochCoeff(tuple):
         """
         if not (isinstance(hop, np.ndarray) and isinstance(coeff, sympy.Expr)):
             raise ValueError('`hop` must be a 1D numpy array and `coeff` a sympy expression.')
-        if isinstance(coeff, sympy.add.Add):
+        if isinstance(coeff, sympy.Add):
             raise ValueError('`coeff` must be a single term with no sum.')
         return super(BlochCoeff, cls).__new__(cls, [hop, coeff])
 
@@ -93,13 +96,14 @@ class BlochCoeff(tuple):
         else:
             raise NotImplementedError
 
-    def __deepcopy__(self, memo):
-        hop, coeff = self
-        return BlochCoeff(deepcopy(hop), deepcopy(coeff))
-
     def __copy__(self):
+        return self.copy()
+
+    def copy(self):
         hop, coeff = self
-        return BlochCoeff(copy(hop), copy(coeff))
+        # Do not copy 'coeff', as Sympy objects are immutable anyway,
+        # and making a copy breaks equality checking and hashing.
+        return BlochCoeff(copy(hop), coeff)
 
     def tosympy(self, momenta, nsimplify=False):
         hop, coeff = self
@@ -201,7 +205,7 @@ class Model(UserDict):
         else:
             # Try to parse the input with kwant_continuum.sympify
             hamiltonian = kwant_continuum.sympify(hamiltonian, locals=locals)
-            if not isinstance(hamiltonian, sympy.matrices.MatrixBase):
+            if not isinstance(hamiltonian, MatrixBase):
                 hamiltonian = sympy.Matrix([[hamiltonian]])
             hamiltonian = substitute_exponents(hamiltonian)
             free_parameters = list(hamiltonian.atoms(sympy.Symbol))
@@ -241,7 +245,9 @@ class Model(UserDict):
             # * splitting summands in keys
             # * moving numerical factors to values
             # * removing entries which values care np.allclose to zero
-            old_data = {copy(key): copy(val) for key, val in self.items()}
+            # Do not copy key, as Sympy objects are immutable anyway,
+            # and making a copy breaks equality checking and hashing.
+            old_data = {key: copy(val) for key, val in self.items()}
             self.data = {}
             for key, val in old_data.items():
                 for summand in key.expand().powsimp(combine='exp').as_ordered_terms():
@@ -360,6 +366,7 @@ class Model(UserDict):
             result = self.zeros_like()
             result.data = {key: val * other for key, val in self.items()}
         elif isinstance(other, Basic):
+            keep = self.keep
             result = sum((type(self)({key * other: copy(val)},
                                      keep=keep,
                                      momenta=self.momenta)
@@ -396,11 +403,15 @@ class Model(UserDict):
         if isinstance(other, Number):
             result = self.__mul__(other)
         elif isinstance(other, Basic):
-            result = sum((type(self)({other * key: copy(val)},
-                                     keep=self.keep,
+            keep = self.keep
+            # The order 'key * other' is important: we want to force
+            # the implementation of __mul__ of 'key' to be used. This
+            # is correct as long as the symbols in 'key' and 'other' commute.
+            result = sum((type(self)({key * other: copy(val)},
+                                     keep=keep,
                                      momenta=self.momenta)
                          for key, val in self.items()
-                         if (key * other in self.keep or not self.keep)),
+                         if (key * other in keep or not keep)),
                          self.zeros_like())
         else:
             # Otherwise try to multiply every value with other
@@ -454,6 +465,9 @@ class Model(UserDict):
         result.append('}')
         return "".join(result)
 
+    def __copy__(self):
+        return self.copy()
+
     def zeros_like(self):
         """Return an empty model object that inherits the other properties"""
         result = type(self)(shape=self.shape,
@@ -630,7 +644,9 @@ class Model(UserDict):
         """Return a copy."""
         result = self.zeros_like()
         # This is faster than deepcopy of the dict
-        result.data = {copy(k): copy(v) for k, v in self.items()}
+        # Do not copy the keys, as Sympy objects (and BlochCoeffs) are
+        # immutable anyway, and making a copy breaks equality checking and hashing.
+        result.data = {k: copy(v) for k, v in self.items()}
         return result
 
     def lambdify(self, nsimplify=False, *, onsite=False, hopping=False):
@@ -677,7 +693,7 @@ class Model(UserDict):
         """Reshape, see numpy.reshape."""
         result = self.zeros_like()
         result.data = {key: val.reshape(*args, **kwargs) for key, val in self.items()}
-        result.shape, _ = _shape_and_format(self[1].reshape(*args, **kwargs))
+        result.shape, result.format = _shape_and_format(self[1].reshape(*args, **kwargs))
         return result
 
     def allclose(self, other, rtol=1e-05, atol=1e-08, equal_nan=False):
@@ -861,21 +877,21 @@ def _to_bloch_coeff(key, momenta):
     # Expand multiplication of brackets into sums.
     key = sympy.expand(key, power_base=False, power_exp=False,
                        mul=True, log=False, multinomial=False)
-    if isinstance(key, sympy.add.Add):
+    if isinstance(key, sympy.Add):
         raise ValueError("Key cannot be a sum of terms.")
     # Key is a single exponential.
-    if isinstance(key, sympy.power.Pow):
+    if isinstance(key, sympy.Pow):
         base, exp = key.as_base_exp()
         # If the exponential is a hopping, store it
         # with coefficient 1.
         if is_hopping_expo(key):
             hop_expo = key
-            coeff = sympy.numbers.One()
+            coeff = One()
         # If it is not a hopping, it belongs to the coeff.
         else:
             hop, coeff, hop_expo = np.zeros((len(momenta,))), key, None
     # Key is the product of an exponential and some extra stuff.
-    elif sympy.power.Pow in [type(arg) for arg in key.args]:
+    elif sympy.Pow in [type(arg) for arg in key.args]:
         # Check that a natural exponential is present, which also
         # includes momenta in its arguments.
         # First find all exponentials.
@@ -924,7 +940,7 @@ def _to_bloch_coeff(key, momenta):
                for momentum in momenta]
         # We do not allow sympy symbols in the hopping, should
         # be numerical values only.
-        if any([isinstance(item, sympy.symbol.Symbol)
+        if any([isinstance(item, sympy.Symbol)
                         for ele in hop for item in ele.atoms()
                         if isinstance(ele, sympy.Expr)]):
             raise ValueError(
